@@ -21,7 +21,7 @@ Email::MIME - Easy MIME message parsing.
 
 =head1 VERSION
 
-version 1.902
+version 1.904
 
 =head1 SYNOPSIS
 
@@ -111,7 +111,7 @@ very long. Added to that, you have:
 
 =cut
 
-our $VERSION = '1.902';
+our $VERSION = '1.904';
 
 use vars qw[$CREATOR];
 $CREATOR = 'Email::MIME::Creator';
@@ -433,7 +433,7 @@ sub header_str_set {
   $email->content_type_set( 'text/html' );
 
 Change the content type. All C<Content-Type> header attributes
-will remain in tact.
+will remain intact.
 
 =cut
 
@@ -572,7 +572,7 @@ sub body_str_set {
 
   my $ct = parse_content_type($self->content_type);
   Carp::confess("body_str was given, but no charset is defined")
-    unless my $charset = $ct->{attributse}{charset};
+    unless my $charset = $ct->{attributes}{charset};
 
   my $body_octets = Encode::encode($charset, $body_str, 1);
   $self->body_set($body_octets);
@@ -583,7 +583,7 @@ sub body_str_set {
   $email->disposition_set( 'attachment' );
 
 Alter the C<Content-Disposition> of a message. All header attributes
-will remain in tact.
+will remain intact.
 
 =cut
 
@@ -688,7 +688,7 @@ sub parts_add {
 =head2 walk_parts
 
   $email->walk_parts(sub {
-      my $part = @_;
+      my ($part) = @_;
       return if $part->parts > 1; # multipart
       
       if ( $part->content_type =~ m[text/html] ) {
@@ -722,7 +722,11 @@ sub walk_parts {
     return $part;
   };
 
-  $walk->($self);
+  my $rv = $walk->($self);
+
+  undef $walk;
+
+  return $rv;
 }
 
 sub _compose_content_type {
